<?php

namespace Assetdocs\Depart\Http\Controllers;

use App\Http\Controllers\Controller as BaseController;
use Assetdocs\Depart\Interfaces\DepartRepositoryInterface;
use Assetdocs\Depart\Repositories\Presenter\DepartItemTransformer;

/**
 * Pubic API controller class.
 */
class DepartApiController extends BaseController
{
    /**
     * Constructor.
     *
     * @param type \Assetdocs\Depart\Interfaces\DepartRepositoryInterface $depart
     *
     * @return type
     */
    public function __construct(DepartRepositoryInterface $depart)
    {
        $this->middleware('api');

        $this->repository = $depart;
        parent::__construct();
    }

    /**
     * Show depart's list.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function index()
    {
        $departs = $this->repository
            ->pushCriteria(new \Assetdocs\Depart\Repositories\Criteria\DepartPublicCriteria())
            ->setPresenter('\\Assetdocs\\Depart\\Repositories\\Presenter\\DepartListPresenter')
            ->scopeQuery(function($query){
                return $query->orderBy('id','DESC');
            })->paginate();

        $departs['code'] = 2000;
        return response()->json($departs)
                ->setStatusCode(200, 'INDEX_SUCCESS');
    }

    /**
     * Show depart.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function show($slug)
    {
        $depart = $this->repository
            ->scopeQuery(function($query) use ($slug) {
            return $query->orderBy('id','DESC')
                         ->where('slug', $slug);
        })->first(['*']);

        if (!is_null($depart)) {
            $depart         = $this->itemPresenter($module, new DepartItemTransformer);
            $depart['code'] = 2001;
            return response()->json($depart)
                ->setStatusCode(200, 'SHOW_SUCCESS');
        } else {
            return response()->json([])
                ->setStatusCode(400, 'SHOW_ERROR');
        }

    }
}
