<?php

namespace Assetdocs\Depart\Policies;

use App\User;
use Illuminate\Auth\Access\HandlesAuthorization;
use Assetdocs\Depart\Models\Depart;

class DepartPolicy
{
    use HandlesAuthorization;

    /**
     * Determine if the given user can view the depart.
     *
     * @param User $user
     * @param Depart $depart
     *
     * @return bool
     */
    public function view(User $user, Depart $depart)
    {
        if ($user->canDo('depart.depart.view') && $user->is('admin')) {
            return true;
        }

        return $user->id === $depart->user_id;
    }

    /**
     * Determine if the given user can create a depart.
     *
     * @param User $user
     * @param Depart $depart
     *
     * @return bool
     */
    public function create(User $user)
    {
        return  $user->canDo('depart.depart.create');
    }

    /**
     * Determine if the given user can update the given depart.
     *
     * @param User $user
     * @param Depart $depart
     *
     * @return bool
     */
    public function update(User $user, Depart $depart)
    {
        if ($user->canDo('depart.depart.update') && $user->is('admin')) {
            return true;
        }

        return $user->id === $depart->user_id;
    }

    /**
     * Determine if the given user can delete the given depart.
     *
     * @param User $user
     * @param Depart $depart
     *
     * @return bool
     */
    public function destroy(User $user, Depart $depart)
    {
        if ($user->canDo('depart.depart.delete') && $user->is('admin')) {
            return true;
        }

        return $user->id === $depart->user_id;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperUser()) {
            return true;
        }
    }
}
